@@ -190,8 +190,56 @@ ZIMS_DATA = {
         "test_redirect": "-/favicon",
         "test_redirect_to": "I/empty.png",
     },
+    "small.zim": {
+        "filename": "small.zim",
+        "filesize": 41155,
+        "new_ns": True,
+        "mutlipart": False,
+        "zim_uuid": "3581ae7eedd57e6cd2f1c0cab073643f",
+        "metadata_keys": [
+            "Counter",
+            "Creator",
+            "Date",
+            "Description",
+            "Illustration_48x48@1",
+            "Language",
+            "Publisher",
+            "Scraper",
+            "Tags",
+            "Title",
+        ],
+        "test_metadata": "Title",
+        "test_metadata_value": "Test ZIM file",
+        "has_main_entry": True,
+        "has_favicon_entry": True,
+        "has_fulltext_index": False,
+        "has_title_index": True,
+        "has_checksum": True,
+        "checksum": None,
+        "is_valid": True,
+        "entry_count": 2,
+        "all_entry_count": 16,
+        "article_count": 1,
+        "suggestion_string": None,
+        "suggestion_count": None,
+        "suggestion_result": None,
+        "search_string": None,
+        "search_count": None,
+        "search_result": None,
+        "test_path": "main.html",
+        "test_title": "Test ZIM file",
+        "test_mimetype": "text/html",
+        "test_size": 207,
+        "test_content_includes": "Test ZIM file",
+        "test_redirect": None,
+        "test_redirect_to": None,
+    },
 }
 
+skip_if_offline = pytest.mark.skipif(
+    bool(os.getenv("OFFLINE")), reason="OFFLINE environ requested offline-only"
+)
+
 
 def get_pytest_param(name, *fields):
     args = [ZIMS_DATA[name].get(field, f"MISSING-VALUE {field}") for field in fields]
@@ -220,7 +268,7 @@ def all_zims(tmpdir_factory):
     libzim_urls = [
         f"https://github.com/kiwix/kiwix-lib/raw/master/test/data/{name}"
         for name in ("zimfile.zim", "example.zim", "corner_cases.zim")
-    ]
+    ] + ["https://github.com/openzim/zim-testing-suite/raw/main/data/nons/small.zim"]
 
     # download libzim tests
     for url in libzim_urls:
@@ -246,6 +294,7 @@ def test_open_badfile(tmpdir):
         Archive(fpath)
 
 
+@skip_if_offline
 def test_content_ref_keep(all_zims):
     """Get the memoryview on a content and loose the reference on the article.
     We try to load a lot of other articles to detect possible use of dandling pointer
@@ -275,6 +324,7 @@ def test_content_ref_keep(all_zims):
     )
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(["filename", "filesize", "new_ns", "mutlipart", "zim_uuid"])
 )
@@ -298,6 +348,7 @@ def test_reader_archive(all_zims, filename, filesize, new_ns, mutlipart, zim_uui
         assert zim.uuid.hex == zim_uuid
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(
         ["filename", "metadata_keys", "test_metadata", "test_metadata_value"]
@@ -313,8 +364,12 @@ def test_reader_metadata(
     assert zim.metadata_keys == metadata_keys
     if test_metadata:
         assert zim.get_metadata(test_metadata).decode("UTF-8") == test_metadata_value
+        item = zim.get_metadata_item(test_metadata)
+        assert item.mimetype == "text/plain"
+        assert item.size > 1
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(["filename", "new_ns", "has_main_entry", "has_favicon_entry"])
 )
@@ -347,7 +402,10 @@ def test_reader_main_favicon_entries(
             assert zim.get_illustration_item().path == "Illustration_48x48@1"
             assert zim.get_illustration_sizes() == {48}
 
+            assert zim.get_metadata_item("Illustration_48x48@1").mimetype == "image/png"
 
+
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(["filename", "has_fulltext_index", "has_title_index"])
 )
@@ -359,6 +417,7 @@ def test_reader_has_index(all_zims, filename, has_fulltext_index, has_title_inde
     assert zim.has_title_index is has_title_index
 
 
+@skip_if_offline
 @pytest.mark.parametrize(*parametrize_for(["filename", "has_checksum", "is_valid"]))
 def test_reader_checksum(all_zims, filename, has_checksum, is_valid):
     zim = Archive(all_zims / filename)
@@ -371,6 +430,7 @@ def test_reader_checksum(all_zims, filename, has_checksum, is_valid):
     assert zim.check() is is_valid
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(
         [
@@ -421,6 +481,7 @@ def test_reader_suggest_search(
         assert list(suggestion.getResults(0, suggestion_count)) == suggestion_result
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(
         [
@@ -476,6 +537,7 @@ def test_reader_get_entries(
         assert zim.get_entry_by_title(test_title).path == entry.path
 
 
+@skip_if_offline
 @pytest.mark.parametrize(
     *parametrize_for(["filename", "test_redirect", "test_redirect_to"])
 )
@@ -496,6 +558,7 @@ def test_reader_redirect(all_zims, filename, test_redirect, test_redirect_to):
                 target_entry.get_redirect_entry().get_redirect_entry()
 
 
+@skip_if_offline
 @pytest.mark.parametrize(*parametrize_for(["filename"]))
 def test_reader_by_id(all_zims, filename):
     zim = Archive(all_zims / filename)
@@ -506,6 +569,7 @@ def test_reader_by_id(all_zims, filename):
         assert zim._get_entry_by_id(index).get_item()._index >= 0
 
 
+@skip_if_offline
 def test_archive_equality(all_zims):
     class Different:
         def __init__(self, filename):
